@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmain.php,v 1.100 2008/04/24 18:45:14 gruberroland Exp $
+$Id: confmain.php,v 1.103 2009/03/07 16:22:30 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
-  Copyright (C) 2003 - 2007  Roland Gruber
+  Copyright (C) 2003 - 2009  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -114,7 +114,6 @@ if (!isset($_SESSION['conf_typeSettings'])) $_SESSION['conf_typeSettings'] = $co
 
 // index for tab order
 $tabindex = 1;
-$tabindexLink = 1000;
 
 echo $_SESSION['header'];
 
@@ -122,7 +121,9 @@ echo ("<title>" . _("LDAP Account Manager Configuration") . "</title>\n");
 echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n");
 echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 echo ("</head>\n");
-echo ("<body>\n");
+echo ("<body onload=\"configLoginMethodChanged()\">\n");
+echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
+echo "<script type=\"text/javascript\" src=\"config.js\"></script>\n";
 echo ("<p align=\"center\"><a href=\"http://lam.sourceforge.net\" target=\"new_window\">".
 	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p>&nbsp;</p>\n");
 
@@ -150,9 +151,7 @@ echo ("<tr><td align=\"right\"><b>" . _("Server address") . " *: </b></td>".
 	"<input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"serverurl\" value=\"" . $conf->get_ServerURL() . "\">".
 	"</td>\n");
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=201\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '201'), '201');
 echo "</td></tr>\n";
 $tabindex++;
 
@@ -164,9 +163,7 @@ echo ("<tr><td align=\"right\"><b>".
 	_("Tree suffix") . ": </b></td>".
 	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"sufftree\" value=\"" . $conf->get_Suffix('tree') . "\"></td>\n");
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=203\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '203'), '203');
 echo "</td></tr>\n";
 $tabindex++;
 
@@ -186,9 +183,7 @@ if ($conf->get_cacheTimeout() != 15) echo("<option>15</option>\n");
 echo ("</select></td>\n");
 $tabindex++;
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=214\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '214'), '214');
 echo "</td></tr>\n";
 
 // access level is only visible in Pro version
@@ -221,9 +216,7 @@ if (isLAMProVersion()) {
 	echo ("</select></td>\n");
 	$tabindex++;
 	echo "<td>";
-	echo "<a href=\"../help.php?HelpNumber=214\" target=\"lamhelp\">";
-	echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-	echo "</a>\n";
+	printHelpLink(getHelp('', '215'), '215');
 	echo "</td></tr>\n";
 }
 
@@ -245,9 +238,7 @@ echo "<br>\n";
 echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"edittypes\" value=\"" . _("Edit account types") . "\">&nbsp;&nbsp;";
 $tabindex++;
 echo "<input tabindex=\"$tabindex\" type=\"submit\" name=\"editmodules\" value=\"" . _("Edit modules") . "\">&nbsp;&nbsp;";
-echo "<a href=\"../help.php?HelpNumber=217\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '217'), '217');
 $tabindex++;
 
 echo ("</fieldset>");
@@ -283,7 +274,7 @@ for ($i = 0; $i < sizeof($modules); $i++) {
 		$icon = '<img align="middle" src="../../graphics/' . $iconImage . '" alt="' . $iconImage . '"> ';
 	}
 	echo "<legend>$icon<b>" . getModuleAlias($modules[$i], "none") . "</b></legend><br>\n";
-	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, $tabindexLink, 'config');
+	$configTypes = parseHtml($modules[$i], $options[$modules[$i]], $old_options, true, $tabindex, 'config');
 	$_SESSION['conf_types'] = array_merge($configTypes, $_SESSION['conf_types']);
 	echo "</fieldset>\n";
 	echo "<br>";
@@ -326,9 +317,7 @@ else
 }
 echo ("</td>\n");
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=209\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '209'), '209');
 echo "</td></tr>\n";
 
 echo ("</table>\n");
@@ -345,18 +334,14 @@ echo ("<tr><td align=\"right\"><b>".
 	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"scriptservers\" value=\"" . $conf->get_scriptServers(false) . "\"></td>\n");
 $tabindex++;
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=218\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '218'), '218');
 echo "</td></tr>\n";
 echo ("<tr><td align=\"right\"><b>".
 	_("Path to external script") . ": </b></td>".
 	"<td><input tabindex=\"$tabindex\" size=50 type=\"text\" name=\"scriptpath\" value=\"" . $conf->get_scriptPath() . "\"></td>\n");
 $tabindex++;
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=210\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '210'), '210');
 echo "</td></tr>\n";
 echo "<tr><td align=\"right\"><b>". _("Rights for the home directory") . ": </b></td>\n";
 $owr = "";
@@ -399,9 +384,7 @@ echo "<td align=\"center\">\n";
 	echo "</tr></table>";
 	$tabindex++;
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=219\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '219'), '219');
 echo "</td></tr>\n";
 
 echo ("</table>\n");
@@ -412,15 +395,53 @@ echo ("<br>\n");
 // security setings
 echo ("<fieldset><legend><b>" . _("Security settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
+// login method
+echo ("<tr><td align=\"right\"><b>".
+	_("Login method") . ": </b></td>".
+	"<td><select tabindex=\"$tabindex\" name=\"loginMethod\" onchange=\"configLoginMethodChanged()\">\n");
+if ($conf->getLoginMethod() == LAMConfig::LOGIN_LIST) {
+	echo("<option selected value=" . LAMConfig::LOGIN_LIST . ">" . _('Fixed list') . "</option>\n");
+}
+else {
+	echo("<option value=" . LAMConfig::LOGIN_LIST . ">" . _('Fixed list') . "</option>\n");
+}
+if ($conf->getLoginMethod() == LAMConfig::LOGIN_SEARCH) {
+	echo("<option selected value=" . LAMConfig::LOGIN_SEARCH . ">" . _('LDAP search') . "</option>\n");
+}
+else {
+	echo("<option value=" . LAMConfig::LOGIN_SEARCH . ">" . _('LDAP search') . "</option>\n");
+}
+echo ("</select></td>\n");
+$tabindex++;
+echo "<td>";
+printHelpLink(getHelp('', '220'), '220');
+echo "</td></tr>\n";
 // admin list
 $adminText = implode("\n", explode(";", $conf->get_Adminstring()));
-echo ("<tr><td align=\"right\"><b>".
+echo "<tr id=\"trAdminList\"><td align=\"right\">\n";
+echo "<b>".
 	_("List of valid users") . " *: </b></td>".
-	"<td><textarea tabindex=\"$tabindex\" name=\"admins\" cols=75 rows=5>" . $adminText . "</textarea></td>\n");
+	"<td><textarea tabindex=\"$tabindex\" name=\"admins\" cols=75 rows=3>" . $adminText . "</textarea></td>\n";
 echo "<td>";
-echo "<a href=\"../help.php?HelpNumber=207\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '207'), '207');
+echo "</td></tr>\n";
+$tabindex++;
+// login search suffix
+echo "<tr id=\"trLoginSearchSuffix\"><td align=\"right\">\n";
+echo "<b>".
+	_("LDAP suffix") . " *: </b></td>".
+	"<td><input type=\"text\" tabindex=\"$tabindex\" name=\"loginSearchSuffix\" value=\"" . $conf->getLoginSearchSuffix() . "\"  size=50></td>\n";
+echo "<td>";
+printHelpLink(getHelp('', '221'), '221');
+echo "</td></tr>\n";
+$tabindex++;
+// login search filter
+echo "<tr id=\"trLoginSearchFilter\"><td align=\"right\">\n";
+echo "<b>".
+	_("LDAP filter") . " *: </b></td>".
+	"<td><input type=\"text\" tabindex=\"$tabindex\" name=\"loginSearchFilter\" value=\"" . $conf->getLoginSearchFilter() . "\"  size=50></td>\n";
+echo "<td>";
+printHelpLink(getHelp('', '221'), '221');
 echo "</td></tr>\n";
 $tabindex++;
 
@@ -432,9 +453,7 @@ echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
 	"<td align=\"left\"><input tabindex=\"$tabindex\" type=\"password\" name=\"passwd1\"></td>\n");
 $tabindex++;
 echo "<td rowspan=2>";
-echo "<a href=\"../help.php?HelpNumber=212\" target=\"lamhelp\">";
-echo "<img src=\"../../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-echo "</a>\n";
+printHelpLink(getHelp('', '212'), '212');
 echo "</td></tr>\n";
 // reenter password
 echo ("<tr><td align=\"right\"><font color=\"red\"><b>".
@@ -503,6 +522,9 @@ function saveSettings() {
 		if (trim($adminText[$i]) == "") continue;
 		$adminTextNew[] = trim($adminText[$i]);
 	}
+	$conf->setLoginMethod($_POST['loginMethod']);
+	$conf->setLoginSearchFilter($_POST['loginSearchFilter']);
+	$conf->setLoginSearchSuffix($_POST['loginSearchSuffix']);
 	if (!$conf->set_Adminstring(implode(";", $adminTextNew))) {
 		$errors[] = array("ERROR", _("List of admin users is empty or invalid!"));
 	}
