@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: massDoUpload.php,v 1.12 2007/12/30 13:15:39 gruberroland Exp $
+$Id: massDoUpload.php,v 1.13 2008/05/15 17:32:22 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -49,7 +49,7 @@ startSecureSession();
 if (!checkIfWriteAccessIsAllowed()) die();
 
 // Redirect to startpage if user is not loged in
-if (!isset($_SESSION['loggedIn'])) {
+if (!isset($_SESSION['loggedIn']) || ($_SESSION['loggedIn'] !== true)) {
 	metaRefresh("login.php");
 	exit;
 }
