@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: masscreate.php,v 1.78 2008/05/15 17:32:22 gruberroland Exp $
+$Id: masscreate.php,v 1.80 2009/02/07 22:56:36 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2004 - 2006  Roland Gruber
@@ -77,6 +77,7 @@ for ($i = 0; $i < sizeof($types); $i++) {
 }
 echo "</head>\n";
 echo "<body>\n";
+echo "<script type=\"text/javascript\" src=\"wz_tooltip.js\"></script>\n";
 
 // check if account specific page should be shown
 if (isset($_POST['type'])) showMainPage($_POST['type']);
@@ -98,16 +99,20 @@ else {
 	echo "</b></p>\n";
 	
 	echo "<form enctype=\"multipart/form-data\" action=\"masscreate.php\" method=\"post\">\n";
-	echo "<table style=\"border-color: grey\" cellpadding=\"10\" border=\"2\" cellspacing=\"0\">\n";
-	for ($i = 0; $i < sizeof($types); $i++) {
-		echo "<tr>\n";
-		echo "<th class=\"" . $types[$i] . "list-sort\" align=\"center\"><input type=\"radio\" name=\"type\" value=\"" . $types[$i] . "\"></th>\n";
-		echo "<th class=\"" . $types[$i] . "list-sort\" align=\"left\">" . getTypeAlias($types[$i]) . "</th>\n";
-		echo "</tr>\n";
-	}
+	echo "<table style=\"border-color: grey\" cellpadding=\"10\" border=\"0\" cellspacing=\"0\">\n";
+		echo "<tr><td>\n";
+		echo "<select name=\"type\">\n";
+		for ($i = 0; $i < sizeof($types); $i++) {
+			echo "<option value=\"" . $types[$i] . "\">\n";
+				echo getTypeAlias($types[$i]);
+			echo "</option>\n";
+		}
+		echo "</select>\n";
+		echo "</td>\n";
+		echo "<td>\n";
+			echo "<input type=\"submit\" name=\"submit\" value=\"". _("Ok") . "\">\n";
+		echo "</td></tr>\n";
 	echo "</table>\n";
-	echo "<br><br>\n";
-	echo "&nbsp;&nbsp;&nbsp;&nbsp;<input type=\"submit\" name=\"submit\" value=\"". _("Ok") . "\">\n";
 	echo "</form>\n";
 	
 	echo "</body>\n";
@@ -153,9 +158,8 @@ function showMainPage($scope) {
 			echo "<td width=\"50%\">\n";
 			echo "<b>" . _("DN suffix") . "</b>\n";
 			// help link
-			echo "&nbsp;<a href=\"help.php?HelpNumber=361\" target=\"lamhelp\">";
-			echo "<img src=\"../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-			echo "</a>\n";
+			echo "&nbsp;";
+			printHelpLink(getHelp('', '361'), '361');
 			echo "<br>\n";
 				echo "<ul>\n";
 					echo "<li><b>" . _("Identifier") . ":</b> " . "dn_suffix</li>\n";
@@ -166,9 +170,8 @@ function showMainPage($scope) {
 			echo "<td width=\"50%\">\n";
 			echo "<b><font color=\"red\">" . _("RDN identifier") . "</font></b>\n";
 			// help link
-			echo "&nbsp;<a href=\"help.php?HelpNumber=301\" target=\"lamhelp\">";
-			echo "<img src=\"../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-			echo "</a>\n";
+			echo "&nbsp;";
+			printHelpLink(getHelp('', '301'), '301');
 			echo "<br>\n";
 				echo "<ul>\n";
 					echo "<li><b>" . _("Identifier") . ":</b> " . "dn_rdn</li>\n";
@@ -304,9 +307,8 @@ function showColumnData($module, $data, $scope) {
 		echo "</b>\n";
 	}
 	// help link
-	echo "&nbsp;<a href=\"help.php?module=$module&amp;HelpNumber=". $data['help'] . "&amp;scope=" . $scope . "\" target=\"lamhelp\">";
-	echo "<img src=\"../graphics/help.png\" alt=\"" . _('Help') . "\" title=\"" . _('Help') . "\">";
-	echo "</a>\n";
+	echo "&nbsp;";
+	printHelpLink(getHelp($module, $data['help'], $scope), $data['help'], $module, $scope);
 	echo "<br>\n";
 	echo "<ul>\n";
 		echo "<li>\n";
