@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: pdfpage.php,v 1.31 2008/04/28 18:01:15 gruberroland Exp $
+$Id: pdfpage.php,v 1.32 2008/12/27 13:06:42 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   Copyright (C) 2003 - 2006  Michael Duergner
@@ -164,7 +164,7 @@ elseif(isset($_GET['add_new_field'])) {
 elseif(isset($_GET['change'])) {
 	$alter = explode('_',$_GET['change']);
 	$newvalue = $_GET['section_' . $alter[0]];
-	if (isset($alter[1]) && ($alter[1] == 'item')) {
+	if (isset($alter[1]) && ($alter[1] == 'item') && ($newvalue[0] != '_')) {
 		$newvalue = '_' . $newvalue;
 	}
 	$_SESSION['currentPDFStructure'][$alter[0]]['attributes']['NAME'] = $newvalue;
