@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: update_confirm.php,v 1.3 2006/03/26 17:51:25 gruberroland Exp $
+$Id: update_confirm.php,v 1.4 2008/01/01 15:00:46 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.sourceforge.net/projects/lam)
   
@@ -55,6 +55,9 @@ include_once('../../lib/account.inc');
 // start session
 startSecureSession();
 
+// die if no write access
+if (!checkIfWriteAccessIsAllowed()) die();
+
 setlanguage();
 
 $dn = $_POST['dn'];
